@@ -15,8 +15,17 @@ def version():
         - 去掉部分print	# 2.2.3
         - 新增conv_to_queryset方法	# 2.2.3
         - 修复部分bug	# 2.2.4
+    # 2.3 baseDjango项目
+        - StateMsgResultJSONRenderer错误提示    # 2.3.0
+        - autoWiki部分修改
+        - _remove_temp_file修改为默认保存最近访问过的1/3缓存文件
+        - BaseListView支持orm参数, 并可使用`convert_to_bool_flag`强制转换为bool变量
+        - 拆分.django文件
+        - 增加`.django.judge_db_is_migrating`, 来判断是否正在迁移数据库
+        - 将`remove_temp_file`迁移至.pure中      # 2.3.1
+        - 将adminclass中的导入导出类增加权限验证和自定义取消功能
     """
-    v = "2.2.4"     # 正式版: 2.2.4
+    v = "2.3.1"     # 正式版: 2.3.0
     return v
 
 
