@@ -20,6 +20,7 @@ from django.utils.http import urlquote
 
 from .. import get_model_max_id_in_db
 from .. import reset_db_sequence
+from ..pure import remove_temp_file
 
 import shutil
 # --- 初始化环境 ---
@@ -28,62 +29,11 @@ from tqdm import tqdm
 from pandas._libs.tslibs.timestamps import Timestamp
 from bddjango import get_base_model, get_model_max_id_in_db, old_get_model_max_id_in_db
 from django.contrib.admin.helpers import ACTION_CHECKBOX_NAME
-
-
-def _remove_temp_file(tempdir=TEMPDIR, MAX_TEMPS=5):
-    """
-    清理缓存, 清空tempdir下的所有文件
-    :param tempdir: 文件路径
-    :param MAX_TEMPS: 最大缓存数量
-    """
-    fpath_ls = os.listdir(tempdir)
-    temps = len(fpath_ls)
-
-    if temps < MAX_TEMPS:
-        print(f'...缓存还足够, 不用清理... 缓存容量: {temps}/{MAX_TEMPS}')
-        return False
-    tt = Time()
-
-    tt.sleep(1)
-    print(f'*************** 开始清理缓存 {tempdir} *************')
-    for fpath in fpath_ls:
-        i = 0
-        tt.__init__()
-        while tt.during(5):
-            i += 1
-            dirpath = os.path.join(tempdir, fpath)
-
-            try:
-                if os.path.isdir(dirpath):
-                    # os.removedirs(dirpath)
-                    shutil.rmtree(dirpath)
-                else:
-                    os.remove(dirpath)
-                print(f"~~~ success: 移除文件[{dirpath}]成功! -- 第[{i}]次")
-                break
-            except:
-                print(f"** 第[{i}]次移除文件[{dirpath}]失败...可能文件被占用中?")
-                tt.sleep(1)
-                if i > 3:
-                    print(f"======== Warning: 移除文件[{dirpath}]失败!")
-    print('*************** 缓存清理完毕 *************')
-    return True
-
-
-def remove_temp_file(tempdir=TEMPDIR, MAX_TEMPS=5, desc='---'):
-    """
-    当大于MAX_TEMPS时启动临时文件清理程序
-    """
-    temps = len(os.listdir(tempdir))
-
-    if temps > MAX_TEMPS:
-        t1 = threading.Thread(target=_remove_temp_file, args=(tempdir, MAX_TEMPS, ))
-        t1.start()
-        return True
-    else:
-
-        print(f'{desc} --- 缓存还足够, 不用清理... 缓存文件: {temps}/{MAX_TEMPS}, tempdir: {tempdir}')
-        return False
+import datetime as dt
+from bdtime import tt
+import time
+import pandas as pd
+from django.contrib.auth import get_permission_codename
 
 
 class IDAdmin(admin.ModelAdmin):
@@ -399,6 +349,11 @@ class ImportAdmin(IDAdmin):
     """
     change_list_template = CHANGE_LIST_HTML_PATH
 
+    custom_import_and_export_buttons = True
+    has_import_perm = True      # 导入数据
+    has_export_perm = True      # 全部导出
+    check_import_and_export_perm = True     # 是否检查导入导出按钮的权限
+
     def import_csv(self, request):
         t_import = Time()
         index = 0
@@ -551,6 +506,35 @@ class ImportAdmin(IDAdmin):
     def remove_temp_file(self, tempdir):
         return remove_temp_file(tempdir)
 
+    def changelist_view(self, request, extra_context=None):
+        if not self.check_import_and_export_perm:
+            has_import_perm = has_export_perm = True
+        else:
+            opts = self.opts
+
+            def has_action_permission(opts, action):
+                codename = get_permission_codename(action, opts)
+                has_perm = request.user.has_perm('%s.%s' % (opts.app_label, codename))
+                return has_perm
+
+            has_add_perm = has_action_permission(opts, 'add')
+            has_change_perm = has_action_permission(opts, 'change')
+            has_view_perm = has_action_permission(opts, 'view')
+
+            has_import_perm = self.has_import_perm and has_add_perm and has_change_perm
+            has_export_perm = self.has_export_perm and has_view_perm
+
+        if extra_context is None:
+            extra_context = {}
+        extra_context.update({
+            'custom_import_and_export_buttons': self.custom_import_and_export_buttons,
+            'has_import_perm': has_import_perm,
+            'has_export_perm': has_export_perm,
+        })
+
+        ret = super().changelist_view(request, extra_context=extra_context)
+        return ret
+
 
 class CsvImportExportAdmin(ImportAdmin, ExportCsvMixin):
     """
